use anyhow::{Context, Result};
use chrono::NaiveDate;
use libgitheatmap::heatmap::Heatmap;

fn main() -> Result<()> {
	let args = libgitheatmap::args();

	let since = NaiveDate::parse_from_str(&args.since, "%Y-%m-%d").unwrap();

	let until = args
		.until
		.clone()
		.unwrap_or_else(|| libgitheatmap::get_default_until(since));
	let until = NaiveDate::parse_from_str(&until, "%Y-%m-%d").unwrap();

	let split_months = args.split_months;
	let months_per_row = args.months_per_row;
	let format = args.format;

	let commits = libgitheatmap::get_commits(args, since, until)
		.with_context(|| "Could not fetch commit list")?;

	let heatmap = Heatmap::new(
		since,
		until,
		commits.0,
		commits.1,
		commits.2,
		split_months,
		months_per_row,
		format,
	);

	println!("{heatmap}");

	Ok(())
}
